bft.views — django-bft v0.1 documentation

### Navigation

- index
- next |
- previous |
- django-bft v0.1 documentation »

# bft.views

#### Previous topic

Welcome to django-bft - A Big File Transfer App Written in Django’s documentation!

#### Next topic

bft.models

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- django-bft v0.1 documentation »

© Copyright 2011, Jay McEntire. Created using Sphinx 1.0.7.